@@ -7,7 +7,12 @@ use yansi::Paint;
 use cargo_modules::options::Options;
 
 fn main() -> anyhow::Result<()> {
-    env_logger::init();
+    env_logger::init_from_env({
+        let env = env_logger::Env::default();
+        let key = env_logger::DEFAULT_FILTER_ENV;
+        let value = "cargo_modules=warn";
+        env.filter_or(key, value)
+    });
 
     let args: Vec<_> = env::args().collect();
     debug!("Arguments: {:?}", args);
@@ -18,6 +23,6 @@ fn main() -> anyhow::Result<()> {
     }
 
     let options = Options::from_args();
-
-    options.command.run()
+    let command = options.sanitized_command();
+    command.run()
 }
